summaryrefslogtreecommitdiffstats
path: root/tdecore/tests
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-19 18:46:45 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-19 18:46:45 -0600
commit5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0 (patch)
treed074ed35245d0d44f04cd625c1cafacdc15a13ae /tdecore/tests
parent6e8a7cc94c1eb8b67e91e6dc2f864dfeec51d9cc (diff)
downloadtdelibs-5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0.tar.gz
tdelibs-5bca2e3e42d02f8fed9ffc399ea14f8a05694cb0.zip
Rename KCmdLineArgs to TDECmdLineArgs to avoid conflicts with KDE4
Diffstat (limited to 'tdecore/tests')
-rw-r--r--tdecore/tests/kapptest.cpp2
-rw-r--r--tdecore/tests/kcalendartest.cpp6
-rw-r--r--tdecore/tests/kcmdlineargstest.cpp8
-rw-r--r--tdecore/tests/kglobaltest.cpp2
-rw-r--r--tdecore/tests/kmacroexpandertest.cpp2
-rw-r--r--tdecore/tests/kmdcodectest.cpp6
-rw-r--r--tdecore/tests/kresolvertest.cpp2
-rw-r--r--tdecore/tests/ksocktest.cpp2
-rw-r--r--tdecore/tests/kuniqueapptest.cpp2
-rw-r--r--tdecore/tests/kurltest.cpp2
-rw-r--r--tdecore/tests/startserviceby.cpp2
-rw-r--r--tdecore/tests/testqtargs.cpp12
12 files changed, 24 insertions, 24 deletions
diff --git a/tdecore/tests/kapptest.cpp b/tdecore/tests/kapptest.cpp
index 7e3b47f43..11227517d 100644
--- a/tdecore/tests/kapptest.cpp
+++ b/tdecore/tests/kapptest.cpp
@@ -29,7 +29,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("kapptest", "kapptest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KApplication a;
diff --git a/tdecore/tests/kcalendartest.cpp b/tdecore/tests/kcalendartest.cpp
index 51a40b892..85f464c9e 100644
--- a/tdecore/tests/kcalendartest.cpp
+++ b/tdecore/tests/kcalendartest.cpp
@@ -39,10 +39,10 @@ int main(int argc, char **argv) {
aboutData.addAuthor("Carlos Moro",0, "cfmoro@correo.uniovi.es");
- KCmdLineArgs::init( argc, argv, &aboutData );
- KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+ TDECmdLineArgs::init( argc, argv, &aboutData );
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
KApplication app(false, false);
diff --git a/tdecore/tests/kcmdlineargstest.cpp b/tdecore/tests/kcmdlineargstest.cpp
index 299196810..4aa05a48b 100644
--- a/tdecore/tests/kcmdlineargstest.cpp
+++ b/tdecore/tests/kcmdlineargstest.cpp
@@ -25,16 +25,16 @@ int
main(int argc, char *argv[])
{
KLocale::setMainCatalogue("tdelibs");
- KCmdLineArgs::init( argc, argv, "testapp", description, version);
+ TDECmdLineArgs::init( argc, argv, "testapp", description, version);
- KCmdLineArgs::addCmdLineOptions( options ); // Add my own options.
+ TDECmdLineArgs::addCmdLineOptions( options ); // Add my own options.
// MyWidget::addCmdLineOptions();
KApplication k( false, false /*true, true*/ );
// Get application specific arguments
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
// Check if an option is set
if (args->isSet("test"))
{
@@ -79,7 +79,7 @@ main(int argc, char *argv[])
int
main(int argc, char *argv[])
{
- KCmdLineArgs::init( argc, argv, "testapp", description, version);
+ TDECmdLineArgs::init( argc, argv, "testapp", description, version);
KApplication k( true, true );
diff --git a/tdecore/tests/kglobaltest.cpp b/tdecore/tests/kglobaltest.cpp
index d03be209e..8904354c5 100644
--- a/tdecore/tests/kglobaltest.cpp
+++ b/tdecore/tests/kglobaltest.cpp
@@ -54,7 +54,7 @@ void testkasciistricmp()
int main(int argc, char *argv[])
{
KApplication::disableAutoDcopRegistration();
- KCmdLineArgs::init( argc, argv, "kglobaltest", 0, 0, 0, 0 );
+ TDECmdLineArgs::init( argc, argv, "kglobaltest", 0, 0, 0, 0 );
KApplication app( false, false );
testkasciistricmp();
diff --git a/tdecore/tests/kmacroexpandertest.cpp b/tdecore/tests/kmacroexpandertest.cpp
index 0c41a309b..11fb4fd8b 100644
--- a/tdecore/tests/kmacroexpandertest.cpp
+++ b/tdecore/tests/kmacroexpandertest.cpp
@@ -51,7 +51,7 @@ protected:
int main(int argc, char *argv[])
{
- KCmdLineArgs::init(argc, argv, ":", "", "", "");
+ TDECmdLineArgs::init(argc, argv, ":", "", "", "");
KApplication app(false,false);
TQString s, s2;
diff --git a/tdecore/tests/kmdcodectest.cpp b/tdecore/tests/kmdcodectest.cpp
index e74d6f4b4..a6ce6431d 100644
--- a/tdecore/tests/kmdcodectest.cpp
+++ b/tdecore/tests/kmdcodectest.cpp
@@ -334,9 +334,9 @@ int main (int argc, char *argv[])
KCmdLineLastOption
};
- KCmdLineArgs::init( argc, argv, "kmdcodectest", description, version );
- KCmdLineArgs::addCmdLineOptions( options );
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs::init( argc, argv, "kmdcodectest", description, version );
+ TDECmdLineArgs::addCmdLineOptions( options );
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
int count = args->count();
KApplication app;
diff --git a/tdecore/tests/kresolvertest.cpp b/tdecore/tests/kresolvertest.cpp
index 1c2272c11..ca5afe0eb 100644
--- a/tdecore/tests/kresolvertest.cpp
+++ b/tdecore/tests/kresolvertest.cpp
@@ -411,7 +411,7 @@ int TestApp::newInstance(TQValueList<TQCString> /*params*/)
int main(int argc, char **argv)
{
KAboutData about("socktest2", "SockTest", "1.0");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KUniqueApplication::addCmdLineOptions();
/* TestApp a;
diff --git a/tdecore/tests/ksocktest.cpp b/tdecore/tests/ksocktest.cpp
index fe33ec771..62fc74905 100644
--- a/tdecore/tests/ksocktest.cpp
+++ b/tdecore/tests/ksocktest.cpp
@@ -58,7 +58,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("socktest", "SockTest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KApplication::addCmdLineOptions();
KApplication app;
diff --git a/tdecore/tests/kuniqueapptest.cpp b/tdecore/tests/kuniqueapptest.cpp
index b1d700c8b..f696711a5 100644
--- a/tdecore/tests/kuniqueapptest.cpp
+++ b/tdecore/tests/kuniqueapptest.cpp
@@ -44,7 +44,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("kuniqueapptest", "kuniqueapptest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KUniqueApplication::addCmdLineOptions();
if (!TestApp::start())
diff --git a/tdecore/tests/kurltest.cpp b/tdecore/tests/kurltest.cpp
index 563eb8937..ddfbc8f7a 100644
--- a/tdecore/tests/kurltest.cpp
+++ b/tdecore/tests/kurltest.cpp
@@ -82,7 +82,7 @@ void testAdjustPath()
int main(int argc, char *argv[])
{
KApplication::disableAutoDcopRegistration();
- KCmdLineArgs::init( argc, argv, "kurltest", 0, 0, 0, 0 );
+ TDECmdLineArgs::init( argc, argv, "kurltest", 0, 0, 0, 0 );
KApplication app( false, false );
KURL::List lst;
diff --git a/tdecore/tests/startserviceby.cpp b/tdecore/tests/startserviceby.cpp
index 93e6716ef..cf9717499 100644
--- a/tdecore/tests/startserviceby.cpp
+++ b/tdecore/tests/startserviceby.cpp
@@ -28,7 +28,7 @@ int
main(int argc, char *argv[])
{
KAboutData about("kapptest", "kapptest", "version");
- KCmdLineArgs::init(argc, argv, &about);
+ TDECmdLineArgs::init(argc, argv, &about);
KApplication a;
diff --git a/tdecore/tests/testqtargs.cpp b/tdecore/tests/testqtargs.cpp
index c9e933c51..97c545e1e 100644
--- a/tdecore/tests/testqtargs.cpp
+++ b/tdecore/tests/testqtargs.cpp
@@ -1,5 +1,5 @@
/*
- testqtargs -- is there really a bug in KCmdLineArgs or am I on crack?
+ testqtargs -- is there really a bug in TDECmdLineArgs or am I on crack?
I used the following compile options:
@@ -64,10 +64,10 @@ int main(int argc, char *argv[])
"1.0", I18N_NOOP("testqtargs"), KAboutData::License_GPL,
"", "", "", "");
- KCmdLineArgs::init(argc, argv, &aboutData);
- KCmdLineArgs::addCmdLineOptions(options);
+ TDECmdLineArgs::init(argc, argv, &aboutData);
+ TDECmdLineArgs::addCmdLineOptions(options);
- KCmdLineArgs *qtargs = KCmdLineArgs::parsedArgs("qt");
+ TDECmdLineArgs *qtargs = TDECmdLineArgs::parsedArgs("qt");
for (int i = 0; i < qtargs->count(); i++)
{
tqDebug("qt arg[%d] = %s", i, qtargs->arg(i));
@@ -75,8 +75,8 @@ int main(int argc, char *argv[])
KApplication app;
- KCmdLineArgs *kdeargs = KCmdLineArgs::parsedArgs("tde");
- KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+ TDECmdLineArgs *kdeargs = TDECmdLineArgs::parsedArgs("tde");
+ TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
// An arg set by Qt
if(qtargs->isSet("background"))